Bug#778757: Close

Vincent Lefevre vincent at vinc17.net
Thu Apr 30 00:42:59 UTC 2015


Control: tags -1 patch

On 2015-04-29 06:21:47 +0200, Anton Gladky wrote:
> Thanks for diving into it! It would be excellent if you prepare a patch.
> So we will close the bug quickly.

I've attached my patch. I had to solve another problem in addition to
the normal installation: the rename to gnuplot5.info and similar changes
from gnuplot to gnuplot5, so that gnuplot5-doc is co-installable with
gnuplot-doc and the info directory can make both versions appear:

* GNUPLOT: (gnuplot).           An Interactive Plotting Program
* GNUPLOT5: (gnuplot5).         An Interactive Plotting Program

-- 
Vincent Lefèvre <vincent at vinc17.net> - Web: <https://www.vinc17.net/>
100% accessible validated (X)HTML - Blog: <https://www.vinc17.net/blog/>
Work: CR INRIA - computer arithmetic / AriC project (LIP, ENS-Lyon)
-------------- next part --------------
diff -aurd gnuplot5-5.0.0+dfsg1~/debian/rules gnuplot5-5.0.0+dfsg1/debian/rules
--- gnuplot5-5.0.0+dfsg1~/debian/rules	2015-04-28 21:05:01.000000000 +0200
+++ gnuplot5-5.0.0+dfsg1/debian/rules	2015-04-30 01:57:36.660693227 +0200
@@ -42,7 +42,7 @@
 	dh_auto_build -a -- -C $(BUILDDIR_NOX)/src
 	dh_auto_build -a -- -C $(BUILDDIR_X11) pkglibexecdir='$$(libexecdir)'
 	dh_auto_build -a -- -C $(BUILDDIR_QT) pkglibexecdir='$$(libexecdir)'
-	cd $(BUILDDIR_X11)/docs; $(MAKE) pdf; $(MAKE) ps; $(MAKE) html; ls
+	cd $(BUILDDIR_X11)/docs; $(MAKE) pdf; $(MAKE) ps; $(MAKE) html; $(MAKE) info; ls
 	cd $(BUILDDIR_X11)/tutorial; $(MAKE) pdf; $(MAKE) ps; ls
 
 override_dh_auto_install:
@@ -62,6 +62,9 @@
 	mv $(CURDIR)/debian/tmp/QT/usr/share/man/man1/gnuplot.1 $(CURDIR)/debian/tmp/QT/usr/share/man/man1/gnuplot5-qt.1
 	mv $(CURDIR)/debian/tmp/QT/usr/share/gnuplot5/gnuplot.gih $(CURDIR)/debian/tmp/QT/usr/share/gnuplot5/gnuplot5-qt.gih
 
+override_dh_installinfo:
+	dh_installinfo -pgnuplot5-doc $(BUILDDIR_X11)/docs/gnuplot5.info
+
 override_installchangelogs:
 	dh_installchangelogs -pgnuplot5-doc ChangeLog
 
diff -aurd gnuplot5-5.0.0+dfsg1~/docs/Makefile.am gnuplot5-5.0.0+dfsg1/docs/Makefile.am
--- gnuplot5-5.0.0+dfsg1~/docs/Makefile.am	2015-04-30 00:18:18.000000000 +0200
+++ gnuplot5-5.0.0+dfsg1/docs/Makefile.am	2015-04-30 01:57:36.660693227 +0200
@@ -81,7 +81,7 @@
 CLEANFILES = allterm.h gnuplot.tex gnuplot.dvi gnuplot.aux gnuplot.log	\
 gnuplot.toc gnuplot.ps gpcard.dvi gpcard.log gpcard.ps alldoc2gih	\
 doc2gih gnuplot.gih doc2hlp gnuplot.hlp gnuplot.idx gnuplot.ilg		\
-gnuplot.ind gnuplot.info* gnuplot.out doc2ipf gnuplot.ipf doc2ms	\
+gnuplot.ind gnuplot5.info* gnuplot.out doc2ipf gnuplot.ipf doc2ms	\
 gnuplot.ms doc2rnh gnuplot.rnh doc2rtf gnuplot.rtf gnuplot.nroff	\
 checkdoc gnuplot.txt gnuplot.tmp VERSION gnuplot.4tc gnuplot.4ct	\
 gnuplot.idv gnuplot.xref gnuplot.lg figures pdffigures.*		\
@@ -299,7 +299,7 @@
 	$(LINK) $^
 
 ### GNU info format
-info: gnuplot.info
+info: gnuplot5.info
 
 # Thanks to Bruce Ravel for doc2texi.el!
 gnuplot.texi gnuplot-eldoc.el: $(srcdir)/doc2texi.el $(srcdir)/gnuplot.doc
@@ -322,16 +322,16 @@
 	   echo "No emacs found - cannot create gnuplot-eldoc.elc file" ; \
 	fi
 
-gnuplot.info: gnuplot.texi
-	$(MAKEINFO) -I$(srcdir) $(srcdir)/gnuplot.texi --no-split --force --output=$@
+gnuplot5.info: gnuplot.texi
+	$(MAKEINFO) -I$(srcdir) gnuplot.texi --no-split --force --output=$@
 
-install-info: gnuplot.info
+install-info: gnuplot5.info
 	$(top_srcdir)/mkinstalldirs $(DESTDIR)$(infodir)
-	$(INSTALL_DATA) gnuplot.info $(DESTDIR)$(infodir)/gnuplot.info
+	$(INSTALL_DATA) gnuplot5.info $(DESTDIR)$(infodir)/gnuplot5.info
 	@if (install-info --version && \
 	     install-info --version | fgrep -i -v debian) >/dev/null 2>&1; then \
-	  echo "install-info --info-dir=$(DESTDIR)$(infodir) $(DESTDIR)$(infodir)/gnuplot.info";\
-	  install-info --info-dir=$(DESTDIR)$(infodir) $(DESTDIR)$(infodir)/gnuplot.info || :;\
+	  echo "install-info --info-dir=$(DESTDIR)$(infodir) $(DESTDIR)$(infodir)/gnuplot5.info";\
+	  install-info --info-dir=$(DESTDIR)$(infodir) $(DESTDIR)$(infodir)/gnuplot5.info || :;\
 	else : ; fi
 
 # this is how to make OS/2 ipfc documentation
diff -aurd gnuplot5-5.0.0+dfsg1~/docs/doc2texi.el gnuplot5-5.0.0+dfsg1/docs/doc2texi.el
--- gnuplot5-5.0.0+dfsg1~/docs/doc2texi.el	2014-10-01 04:36:59.000000000 +0200
+++ gnuplot5-5.0.0+dfsg1/docs/doc2texi.el	2015-04-30 01:58:50.902474340 +0200
@@ -79,7 +79,7 @@
 ;;
 ;; Then you can do
 ;;
-;;      makeinfo gnuplot.info
+;;      makeinfo gnuplot5.info
 ;;
 ;; You may want to use the --no-split option.
 ;;
@@ -155,7 +155,7 @@
   "\\input texinfo   @c -*-texinfo-*-
 
 @c %**start of header
- at setfilename gnuplot.info
+ at setfilename gnuplot5.info
 @settitle Gnuplot: An Interactive Plotting Program
 @setchapternewpage odd
 @c %**end of header
@@ -167,7 +167,7 @@
 
 @dircategory Math
 @direntry
 * GNUPLOT: (gnuplot).             An Interactive Plotting Program
 @end direntry
 
 @ifnottex
@@ -460,7 +460,7 @@
     ("sun" "sun")
     ("vms" "vws"))
 
-  "Additional terminals to add to the converted gnuplot.info file.
+  "Additional terminals to add to the converted gnuplot5.info file.
 
 The CARs of the items are strings to match against
 `system-configuration', and the CDRs are the elements to add to
@@ -167,7 +167,7 @@
 @dircategory Math
 @direntry
-* GNUPLOT: (gnuplot).             An Interactive Plotting Program
+* GNUPLOT5: (gnuplot5).           An Interactive Plotting Program
 @end direntry
 


More information about the debian-science-maintainers mailing list